summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorburnus <burnus@138bc75d-0d04-0410-961f-82ee72b054a4>2008-09-24 07:08:22 +0000
committerburnus <burnus@138bc75d-0d04-0410-961f-82ee72b054a4>2008-09-24 07:08:22 +0000
commit828608173811427bad8a09f9d71306de99b886a7 (patch)
tree657ede36df28bcb24c2fbd9d883065585bf5de4f
parent62754d540b5a88cea4a4eafe2fa90cbb3826bca8 (diff)
downloadppe42-gcc-828608173811427bad8a09f9d71306de99b886a7.tar.gz
ppe42-gcc-828608173811427bad8a09f9d71306de99b886a7.zip
2008-09-24 Tobias Burnus <burnus@net-b.de>
* options.c (set_default_std_flags,gfc_init_options): Add comment: keep in sync with libgfortran. 2008-09-24 Tobias Burnus <burnus@net-b.de> * runtime/compile_options.c (init_compile_options): Sync flags with front end. git-svn-id: svn+ssh://gcc.gnu.org/svn/gcc/trunk@140625 138bc75d-0d04-0410-961f-82ee72b054a4
-rw-r--r--gcc/fortran/ChangeLog5
-rw-r--r--gcc/fortran/options.c7
-rw-r--r--libgfortran/ChangeLog5
-rw-r--r--libgfortran/runtime/compile_options.c6
4 files changed, 18 insertions, 5 deletions
diff --git a/gcc/fortran/ChangeLog b/gcc/fortran/ChangeLog
index 3d99ae35e70..c8301f659b7 100644
--- a/gcc/fortran/ChangeLog
+++ b/gcc/fortran/ChangeLog
@@ -1,5 +1,10 @@
2008-09-24 Tobias Burnus <burnus@net-b.de>
+ * options.c (set_default_std_flags,gfc_init_options):
+ Add comment: keep in sync with libgfortran.
+
+2008-09-24 Tobias Burnus <burnus@net-b.de>
+
PR fortran/37626
* trans-array.c (gfc_trans_deferred_array): Don't auto-deallocate
result variables.
diff --git a/libgfortran/ChangeLog b/libgfortran/ChangeLog
index fff673d83f6..660be4329ea 100644
--- a/libgfortran/ChangeLog
+++ b/libgfortran/ChangeLog
@@ -1,3 +1,8 @@
+2008-09-24 Tobias Burnus <burnus@net-b.de>
+
+ * runtime/compile_options.c (init_compile_options):
+ Sync flags with front end.
+
2008-09-22 Jerry DeLisle <jvdelisle@gcc.gnu.org
PR libfortran/37498
diff --git a/libgfortran/runtime/compile_options.c b/libgfortran/runtime/compile_options.c
index c62fe1c326a..2c0a94517d3 100644
--- a/libgfortran/runtime/compile_options.c
+++ b/libgfortran/runtime/compile_options.c
@@ -140,10 +140,10 @@ set_options (int num, int options[])
void
init_compile_options (void)
{
- compile_options.warn_std = GFC_STD_F95_OBS | GFC_STD_F95_DEL
- | GFC_STD_F2003 | GFC_STD_LEGACY;
+ compile_options.warn_std = GFC_STD_F95_DEL | GFC_STD_LEGACY;
compile_options.allow_std = GFC_STD_F95_OBS | GFC_STD_F95_DEL
- | GFC_STD_F2003 | GFC_STD_F95 | GFC_STD_F77 | GFC_STD_GNU | GFC_STD_LEGACY;
+ | GFC_STD_F2003 | GFC_STD_F2008 | GFC_STD_F95 | GFC_STD_F77
+ | GFC_STD_GNU | GFC_STD_LEGACY;
compile_options.pedantic = 0;
compile_options.dump_core = 0;
compile_options.backtrace = 0;
OpenPOWER on IntegriCloud
diff --git a/gcc/fortran/options.c b/gcc/fortran/options.c
index 52174b3d187..e84b3b15370 100644
--- a/gcc/fortran/options.c
+++ b/gcc/fortran/options.c
@@ -37,7 +37,8 @@ gfc_option_t gfc_option;
/* Set flags that control warnings and errors for different
- Fortran standards to their default values. */
+ Fortran standards to their default values. Keep in sync with
+ libgfortran/runtime/compile_options.c (init_compile_options). */
static void
set_default_std_flags (void)
@@ -48,7 +49,9 @@ set_default_std_flags (void)
gfc_option.warn_std = GFC_STD_F95_DEL | GFC_STD_LEGACY;
}
-/* Get ready for options handling. */
+
+/* Get ready for options handling. Keep in sync with
+ libgfortran/runtime/compile_options.c (init_compile_options). */
unsigned int
gfc_init_options (unsigned int argc, const char **argv)